@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -21,6 +21,8 @@
 
 
 #define S_D 2.5f
+#include <CGAL/config.h> // to include before NDEBUG is defined, to
+                         // workaround the check in the testsuite
 #ifndef NDEBUG
 #define NDEBUG //points are not on circular arcs
 #endif
