@@ -1,9 +1,10 @@
 // Copyright (c) 2002  Max Planck Institut fuer Informatik (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,13 +12,15 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Convex_hull_3/demo/Convex_hull_3/quickhull_3_demo.cpp $
-// $Id: quickhull_3_demo.cpp 44910 2008-08-12 12:58:18Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Convex_hull_3/demo/Convex_hull_3/quickhull_3_demo.cpp $
+// $Id: quickhull_3_demo.cpp 67117 2012-01-13 18:14:48Z lrineau $
 //
 //
 // Author(s)     : Susan Hert
 
+#include <CGAL/config.h>
 
+#ifdef CGAL_USE_GEOMVIEW
 
 #include <CGAL/Homogeneous.h>
 #include <CGAL/point_generators_3.h>
@@ -28,8 +31,6 @@
 #include <CGAL/IO/Geomview_stream.h>
 #include <CGAL/IO/Polyhedron_geomview_ostream.h>
 
-#ifdef CGAL_USE_GEOMVIEW
-
 #ifdef CGAL_USE_LEDA
 #include <CGAL/leda_integer.h>
 typedef leda_integer RT;
@@ -115,7 +116,7 @@ int main(int argc, char* argv[])
   Generator gen(100.0);
 
   // generate num points and copy them to a vector
-  CGAL::copy_n( gen, num, std::back_inserter(points) );
+  CGAL::cpp0x::copy_n( gen, num, std::back_inserter(points) );
 
   // define object to hold convex hull
   CGAL::Object ch_object;
@@ -128,6 +129,8 @@ int main(int argc, char* argv[])
 
 #else
 
+#include <iostream>
+
 int main() {
   std::cerr <<
   "This demo requires geomview, which is not present on this platform\n";
