@@ -8,8 +8,16 @@
 
 #include <CGAL/Filtered_kernel_fwd.h>
 
+template <typename Patch_id>
+class Polyhedron_demo_items;
+
 namespace CGAL {
 
+  namespace Mesh_3 {
+    template <typename Kernel>
+    struct Robust_intersection_traits_3;
+  }
+
   template < typename FT_ >
   struct Simple_cartesian;
 
@@ -32,15 +40,27 @@ namespace CGAL {
              >
   class Polyhedron_3;
   
+// changed since CGAL-3.8-Ic-8
+#if CGAL_VERSION_NR > 1030800008 
+  class Epick;
+#endif
 } // end namespace CGAL
 
 // kernel
-
-typedef CGAL::Epick Kernel;
+namespace polyhedron_type_fwd_h {
+// changed since CGAL-3.8-Ic-8
+#if CGAL_VERSION_NR > 1030800008 
+  typedef CGAL::Epick K1;
+#else
+  typedef CGAL::Filtered_kernel< CGAL::Simple_cartesian<double>, true > K1;
+#endif
+  typedef CGAL::Mesh_3::Robust_intersection_traits_3<K1> Kernel;
+}
 
 // surface mesh
-typedef CGAL::Polyhedron_3<Kernel,
-                           CGAL::Polyhedron_items_3,
+typedef CGAL::Polyhedron_3<polyhedron_type_fwd_h::Kernel,
+                           Polyhedron_demo_items<int>,
+                           // CGAL::Polyhedron_items_3,
                            CGAL::HalfedgeDS_default,
                            std::allocator<int> > Polyhedron;
 
