@@ -49,6 +49,9 @@ public:
   /// @cond SKIP_IN_MANUAL
   typedef typename Base::iterator iterator;
   typedef typename Base::const_iterator const_iterator;
+
+  using Base::erase;
+
   /// @endcond
 
   // Classic CGAL geometric types
@@ -298,7 +301,7 @@ public:
 
 
   bool are_radii_uptodate() const { return m_radii_are_uptodate; }
-  void set_radii_uptodate(bool on) { m_radii_are_uptodate = false; }
+  void set_radii_uptodate(bool /*on*/) { m_radii_are_uptodate = false; }
 
 // Private methods:
 private:
