@@ -56,7 +56,7 @@ struct Trivial_kds: CGAL::Kinetic::Ref_counted<Trivial_kds<Traits> >
   typedef typename Traits::Simulator::Time Time;
   typedef typename Traits::Active_points_1_table::Key Point_key;
   typedef typename Traits::Simulator::Event_key Event_key;
-  CGAL_KINETIC_DECLARE_LISTENERS(typename Traits::Simulator, typename Traits::Active_points_1_table);
+  CGAL_KINETIC_DECLARE_LISTENERS(typename Traits::Simulator, typename Traits::Active_points_1_table)
 public:
   typedef Trivial_event<Point, Time, This> Event;
 
