@@ -1,9 +1,10 @@
 // Copyright (c) 2009 INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/AABB_tree/include/CGAL/AABB_polyhedron_triangle_primitive.h $
-// $Id: AABB_polyhedron_triangle_primitive.h 52790 2009-10-29 10:42:53Z palliez $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/AABB_tree/include/CGAL/AABB_polyhedron_triangle_primitive.h $
+// $Id: AABB_polyhedron_triangle_primitive.h 67117 2012-01-13 18:14:48Z lrineau $
 //
 //
 // Author(s)     : Stéphane Tayeb, Pierre Alliez
@@ -52,6 +53,15 @@ namespace CGAL {
         }
         AABB_polyhedron_triangle_primitive(const Id& handle)
             : m_facet_handle(handle)  { };
+        AABB_polyhedron_triangle_primitive(const Id* ptr)
+            : m_facet_handle(*ptr)  { };
+        template <class Iterator>
+        AABB_polyhedron_triangle_primitive( Iterator it,
+                                            typename boost::enable_if< 
+                                                       boost::is_same<Id,typename Iterator::value_type>
+                                            >::type* =0
+        ) : m_facet_handle(*it)  { }
+
 
         // Default destructor, copy constructor and assignment operator are ok
 
