@@ -1,9 +1,10 @@
 // Copyright (c) 2009 INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/AABB_tree/include/CGAL/AABB_traits.h $
-// $Id: AABB_traits.h 52944 2009-11-10 16:58:02Z stayeb $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/AABB_tree/include/CGAL/AABB_traits.h $
+// $Id: AABB_traits.h 67117 2012-01-13 18:14:48Z lrineau $
 //
 //
 // Author(s) : Stéphane Tayeb, Pierre Alliez, Camille Wormser
@@ -28,6 +29,8 @@
 #include <CGAL/Bbox_3.h>
 #include <CGAL/AABB_intersections.h>
 
+#include <boost/optional.hpp>
+
 namespace CGAL {
 
 /**
@@ -192,6 +195,7 @@ Intersection intersection_object() {return Intersection();}
   // this is not the same do_intersect as the spherical kernel)
   class Compare_distance {
       typedef typename AT::Point Point;
+      typedef typename AT::FT FT;
       typedef typename AT::Primitive Primitive;
   public:
       template <class Solid>
@@ -202,6 +206,16 @@ Intersection intersection_object() {return Intersection();}
           (p, GeomTraits().compute_squared_distance_3_object()(p, bound)), pr)?
           CGAL::SMALLER : CGAL::LARGER;
       }
+
+      template <class Solid>
+      CGAL::Comparison_result operator()(const Point& p, const Solid& pr, const FT& sq_distance) const
+      {
+        return GeomTraits().do_intersect_3_object()
+          (GeomTraits().construct_sphere_3_object()(p, sq_distance),
+           pr) ?
+          CGAL::SMALLER : 
+          CGAL::LARGER;
+      }
   };
 
   Closest_point closest_point_object() {return Closest_point();}
