@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Algebraic_foundations/include/CGAL/Algebraic_extension_traits.h $
-// $Id: Algebraic_extension_traits.h 44362 2008-07-23 14:58:05Z hoffmann $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Algebraic_foundations/include/CGAL/Algebraic_extension_traits.h $
+// $Id: Algebraic_extension_traits.h 67093 2012-01-13 11:22:39Z lrineau $
 //
 //
 // Author(s)     : Michael Hemmer    <hemmer@mpi-inf.mpg.de>
@@ -30,7 +30,7 @@
 
 #include <numeric> // for std::accumulate
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template< class T >
 class Algebraic_extension_traits {
@@ -79,7 +79,7 @@ public:
     };
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // NiX_ALGEBRAIC_NUMBER_TRAITS_H
 // EOF
