@@ -1,9 +1,10 @@
 // Copyright (c) 1997  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Alpha_shapes_3/include/CGAL/Alpha_shape_euclidean_traits_3.h $
-// $Id: Alpha_shape_euclidean_traits_3.h 50408 2009-07-06 20:26:44Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Alpha_shapes_3/include/CGAL/Alpha_shape_euclidean_traits_3.h $
+// $Id: Alpha_shape_euclidean_traits_3.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Tran Kai Frank DA <Frank.Da@sophia.inria.fr>
@@ -20,12 +21,12 @@
 #ifndef CGAL_ALPHA_SHAPE_EUCLIDEAN_TRAITS_3_H
 #define CGAL_ALPHA_SHAPE_EUCLIDEAN_TRAITS_3_H 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class K>
 class Alpha_shape_euclidean_traits_3 : public K {};
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif //CGAL_ALPHA_SHAPE_EUCLIDEAN_TRAITS_3_H
